import { Component, Inject,ViewChild, AfterViewInit, OnInit } from '@angular/core';
import {DataSvc} from "../services/DataSvc";
import * as wjCore from "wijmo/wijmo";
import * as wjInput from "wijmo/wijmo.input";
import * as wjGrid from "wijmo/wijmo.grid";
import * as wjSheet from "wijmo/wijmo.grid.sheet";

@Component({
  selector: 'app-root',
  templateUrl: './app.component.html',
  styleUrls: ['./app.component.css']
})
export class AppComponent {
  public data:wjCore.CollectionView;
  public countries;
  constructor(@Inject(DataSvc) _dataSvc:DataSvc){
    this.data= new wjCore.CollectionView(_dataSvc.getData(10));
    this.countries= _dataSvc.getCountries();
  }
  initFlex(s:wjSheet.FlexSheet,e:wjCore.EventArgs){
    var host= document.createElement('div');
    var flex1 = new wjGrid.FlexGrid(host, {
        autoGenerateColumns: false,
        isReadOnly:true,
        columns: [
            { binding: 'country', header: 'Country' ,isReadOnly:true},
            { binding: 'downloads', header: 'Downloads', format: 'n0', width: 150 },
            { binding: 'sales', header: 'Sales', format: 'n2', width: 150 },
            
        ],
        itemsSource: this.data        
    });
    s.sheets.push(new wjSheet.Sheet(s,flex1,"DataMap"));
    this._addDataMapItemFormatter(s.getColumn('country'),s);
    s.autoSizeRows();
  }
  _addDataMap(editColumn:wjGrid.Column,sheet:wjSheet.FlexSheet){
     var grid = editColumn.grid;
            grid.formatItem.addHandler((s, e:wjGrid.FormatItemEventArgs)=> {
                var editRange = grid.editRange,
                    column = e.panel.columns[e.col];
                // check whether this is an editing cell of the wanted column
                if (!(e.panel.cellType === wjGrid.CellType.Cell &&
                    column === editColumn && e.row!==0)) {
                    return;
                }

                // hide standard editor (don't remove!)
                if (e.cell.firstChild) {
                 //   e.cell.firstChild.style.display = 'none';
                }
                e.cell.innerHTML = "";
                // add custom editor
                var editorRoot = document.createElement('div');
                var input;
                if (column.dataType === wjCore.DataType.String) {
                    input = new wjInput.AutoComplete(editorRoot);
                    input.isRequired = false;
                    input.itemsSource = this.countries;
                    input.selectedValue = sheet.getCellData(e.row, e.col, false);
                    console.log(e.row,e.col,sheet.getCellData(e.row, e.col, false),input.selectedValue)
                }               
                e.cell.appendChild(editorRoot);                
                input.focus();
                var selection;
                input.gotFocus.addHandler((s,e)=>{                   
                    selection=sheet.selection;
                });
                input.lostFocus.addHandler((s,e)=>{
                    if(selection.row!=0){
                        sheet.setCellData(selection.row,selection.col,input.selectedValue);
                    }
                });               
            });

  }
  _addDataMapItemFormatter(editColumn:wjGrid.Column,sheet:wjSheet.FlexSheet){
    var grid = editColumn.grid;
           grid.itemFormatter=(panel,row,col,cell)=> {
               var editRange = grid.editRange,
                   column = panel.columns[col];
               // check whether this is an editing cell of the wanted column
               if (!(panel.cellType === wjGrid.CellType.Cell &&
                   column === editColumn && row!==0)) {
                   return;
               }

               // hide standard editor (don't remove!)
               if (cell.firstChild) {
                //   e.cell.firstChild.style.display = 'none';
               }
               cell.innerHTML = "";
               // add custom editor
               var editorRoot = document.createElement('div');
               var input;
               if (column.dataType === wjCore.DataType.String) {
                   input = new wjInput.AutoComplete(editorRoot);
                   input.isRequired = false;
                   input.itemsSource = this.countries;
                   input.selectedValue = sheet.getCellData(row, col, false);
                   console.log(row,col,sheet.getCellData(row, col, false),input.selectedValue)
               }               
               cell.appendChild(editorRoot);                
               input.focus();
               var selection;
               input.gotFocus.addHandler((s,e)=>{                   
                   selection=sheet.selection;
               });
               input.lostFocus.addHandler((s,e)=>{
                   if(selection.row!=0){
                       sheet.setCellData(selection.row,selection.col,input.selectedValue);
                   }
               });               
           };

 }
}
